/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var Templates = function()
{
	var templates = {};
	
	/**
		Initialize the page.
	*/
	templates.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', templates.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabValidator('settings.info', templates.validateTemplate);
			
			// Cloned properties
			Buttons.addClickHandler('moveLeft', Forms.moveSelectedOnClick);
			Buttons.addClickHandler('moveRight', Forms.moveSelectedOnClick);
			Events.addEventHandler('uncloned_properties', 'dblclick', Forms.moveSelectedOnClick);
			Events.addEventHandler('cloned_properties', 'dblclick', Forms.moveSelectedOnClick);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'REPORTERCLONETEMPLATE', 'item-id': itemId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);

			TabControl.addTabActivateListener('main.history', History.loadOnce);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'REPORTERCLONETEMPLATE'};
			var tableAttributes = {'table-id': 'templates'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
	
	
	templates.validateTemplate = function()
	{
		var frm = document.forms['template'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		return true;
	}

	// Submit the form
	templates.save = function()
	{
		var frm = document.forms['template'];
		if (TabControl.validateActiveTab('settings'))
		{
			for (var i = 0; i < frm.cloned_properties.length; i++)
			{
				frm.cloned_properties[i].selected = true;
			}
			for (var i = 0; i < frm.uncloned_properties.length; i++)
			{
				frm.uncloned_properties[i].selected = true;
			}
			frm.submit();
		}
	}	

	function moveBetween(list1, list2, exceptMandatory)
	{
		var moved = 0;
		for(i=0; i < list1.options.length; i++) // >
		{
			if (list1.options[i].selected)
			{
				if (exceptMandatory && list1.options[i].text.indexOf('×') > 0)
				{
					Forms.showNotification(list1, list1.options[i].text + ' is mandatory', null, 'pointer-left');
				}
				else
				{
					moved++;
					list2.options[list2.options.length] = new Option(list1.options[i].text, list1.options[i].value, false, true);
					list1.options[i] = null;
					i--;
				}
			}
		}
	}

	return templates;
}();

Doc.onLoad(Templates.initPage);
